Documentation
¶
Overview ¶
Package testing provides test helpers for vecna.
Index ¶
- func AssertChildCount(t *testing.T, f *vecna.Filter, expected int)
- func AssertError(t *testing.T, f *vecna.Filter)
- func AssertField(t *testing.T, f *vecna.Filter, expected string)
- func AssertNoError(t *testing.T, f *vecna.Filter)
- func AssertOp(t *testing.T, f *vecna.Filter, expected vecna.Op)
- func NewTestBuilder(t *testing.T) *vecna.Builder[DocumentMetadata]
- type DocumentMetadata
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertChildCount ¶
AssertChildCount fails the test if the filter doesn't have the expected number of children.
func AssertError ¶
AssertError fails the test if the filter does not have an error.
func AssertField ¶
AssertField fails the test if the filter field doesn't match expected.
func AssertNoError ¶
AssertNoError fails the test if the filter has an error.
func NewTestBuilder ¶
func NewTestBuilder(t *testing.T) *vecna.Builder[DocumentMetadata]
NewTestBuilder creates a Builder[DocumentMetadata] for testing. Fails the test if builder creation fails.
Types ¶
Click to show internal directories.
Click to hide internal directories.